==> haskell-hspec-wai-json-0.11.0-511-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-wai-json
version:              0.11.0
visibility:           public
id:                   hspec-wai-json-0.11.0-JS2bt383G3t9PJfQItPLAt
key:                  hspec-wai-json-0.11.0-JS2bt383G3t9PJfQItPLAt
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Testing JSON APIs with hspec-wai
description:          Testing JSON APIs with hspec-wai
category:             Testing
abi:                  6225232af41401cb3d7d9b80d06e0c14
exposed:              True
exposed-modules:      Test.Hspec.Wai.JSON
hidden-modules:       Paths_hspec_wai_json
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-wai-json-0.11.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-wai-json-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai-json
hs-libraries:         HShspec-wai-json-0.11.0-JS2bt383G3t9PJfQItPLAt
depends:
    aeson-2.1.2.1-IkP1OjeNuTxglWxWeIvI9
    aeson-qq-0.8.4-9fWAlUEU7OqBc0a3vldpwc base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-3YsL0BQanAbLHEhUwcLo8j
    hspec-wai-0.11.1-1yKYcUa4MjlILSlkaxy5ne template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock

haddock-html:         /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-wai-json-0.11.0-512-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-wai-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 hspec-wai-json
version:              0.11.0
visibility:           public
id:                   hspec-wai-json-0.11.0-BaVn7U7qhIJEfP289OyGLZ
key:                  hspec-wai-json-0.11.0-BaVn7U7qhIJEfP289OyGLZ
license:              MIT
copyright:
    (c) 2012-2014 Fujimura Daisuke,
    (c) 2014-2018 Simon Hengel

maintainer:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

author:
    Fujimura Daisuke <me@fujimuradaisuke.com>,
    Simon Hengel <sol@typeful.net>

homepage:             https://github.com/hspec/hspec-wai#readme
synopsis:             Testing JSON APIs with hspec-wai
description:          Testing JSON APIs with hspec-wai
category:             Testing
abi:                  c2ea0f8d6ab44315d3ca1d192fb3e2f1
exposed:              True
exposed-modules:      Test.Hspec.Wai.JSON
hidden-modules:       Paths_hspec_wai_json
import-dirs:          /usr/lib/ghc-9.2.8/site-local/hspec-wai-json-0.11.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/hspec-wai-json-0.11.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-wai-json
hs-libraries:         HShspec-wai-json-0.11.0-BaVn7U7qhIJEfP289OyGLZ
depends:
    aeson-2.1.2.1-IkP1OjeNuTxglWxWeIvI9
    aeson-qq-0.8.4-9fWAlUEU7OqBc0a3vldpwc base-4.16.4.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-3YsL0BQanAbLHEhUwcLo8j
    hspec-wai-0.11.1-Hr6jrVEK6CyGfnuuTZxv5x template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-hspec-wai-json/html/hspec-wai-json.haddock

haddock-html:         /usr/share/doc/haskell-hspec-wai-json/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
